use Test::Simple tests => 7;
use strict;
use DE_EPAGES::Core::API::Error qw ( ExistsError );
use DE_EPAGES::Core::API::SystemCommand qw ( SystemCommand );
use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Core::API::File qw ( DeleteDirectory DeleteFile GetFileNames );
use DE_EPAGES::Database::API::BackupMySQL;
use DE_EPAGES::Database::API::Config qw ( DatabaseConfig );

sub Main {

    my $Store = -f "$ENV{EPAGES_CONFIG}/Database.d/Store.conf" ? 'Store' : 'Site';
    my $BackupHost = DatabaseConfig($Store)->get( 'Connection', 'Backup' );
    $BackupHost =~ s/\s+$//g;
    my $TestHost = $BackupHost eq 'localhost' ? '127.0.0.1' : 'localhost';

    CleanUp();
    Test_IsMySQLDB();
    ok ( Test_MySQLBackup($Store) );
    ok ( Test_MySQLDumpFile() );
    ok ( Test_MySQLDumps($Store) );

    DatabaseConfig($Store)->set( 'Connection', 'BackupHost', $TestHost );
    ok ( Test_MySQLDumps($Store) );

    DatabaseConfig($Store)->set( 'Connection', 'BackupHost', $BackupHost );
    CleanUp();
}

RunScript( Sub => \&Main);

sub Test_MySQLBackup {
    my ($Store) = @_;
    eval {
        my $Script = "$ENV{'EPAGES_CARTRIDGES'}/DE_EPAGES/Database/Scripts/MySQLBackup.pl";
        SystemCommand("$ENV{PERL} $Script -full -storename $Store -dumpdir '/tmp/MySQLDump'");
    };
    return ExistsError() ? 0 : 1;
}

sub Test_MySQLDumpFile {
    return scalar @{ GetFileNames('/tmp/MySQLDump') };
}

sub Test_MySQLDumps {
    my ($Store) = @_;
    eval {
        my $Script = "$ENV{'EPAGES_CARTRIDGES'}/DE_EPAGES/Database/Scripts/MySQLDumps.pl";
        SystemCommand("$ENV{PERL} $Script -fullbackup -target /tmp/full_backup_db -storename $Store");
    };
    return ExistsError() ? 0 : 1;
}

sub Test_IsMySQLDB {
    my $hSettingsMySQL = { 'datasource' => 'dbi:mysql:host=172.24.50.9' };
    my $hSettingsGalera = { 'datasource' => 'dbi:galera:host=172.24.50.9' };
    my $hSettingsSybase = { 'datasource' => 'dbi:sybase:host=172.24.50.9' };

    ok( DE_EPAGES::Database::API::BackupMySQL::IsMySQLDB($hSettingsMySQL), '_IsMySQLDB datasource mysql' );
    ok( DE_EPAGES::Database::API::BackupMySQL::IsMySQLDB($hSettingsGalera), '_IsMySQLDB datasource mysql' );
    ok( !DE_EPAGES::Database::API::BackupMySQL::IsMySQLDB($hSettingsSybase), '_IsMySQLDB datasource mysql' );
}

sub CleanUp {
    DeleteDirectory('/tmp/MySQLDump', {'recursive' => 1});
    DeleteFile('/tmp/fullbackup');
}

1;
