﻿package DE_EPAGES::Ebay::t::unit::filterSellerProfiles;
use base DE_EPAGES::Core::API::Test;

use strict;
use utf8;
use Test::More;
use DE_EPAGES::Ebay::t::unit::filterSellerProfilesData qw (EBAY_GET_SELLER_PROFILE_RESPONSE);
use DE_EPAGES::Ebay::API::Object::EbayShopEnvironment;

sub test {
    my $self = shift;

    $self->test_payment_seller_profile();
    $self->test_shipping_seller_profile();
    $self->test_return_policy_seller_profile();

    $self->test_default_payment_seller_profile();
    $self->test_default_shipping_seller_profile();
    $self->test_default_return_seller_profile();


    done_testing();
}

sub test_payment_seller_profile {
    my $self = shift;

    my $ahSellerProfiles = DE_EPAGES::Ebay::API::Object::EbayShopEnvironment->filterSellerProfiles(EBAY_GET_SELLER_PROFILE_RESPONSE,'PAYMENT');

    is($ahSellerProfiles->[0]->{'ProfileName'},'PayPal:Sonstige / siehe Artikelbeschreibung','First Seller Profile PAYMENT');
    is(scalar @{$ahSellerProfiles},2,'One Seller Profile PAYMENT');
}

sub test_shipping_seller_profile {
    my $self = shift;

    my $ahSellerProfiles = DE_EPAGES::Ebay::API::Object::EbayShopEnvironment->filterSellerProfiles(EBAY_GET_SELLER_PROFILE_RESPONSE,'SHIPPING');

    is($ahSellerProfiles->[0]->{'ProfileName'},'Pauschal:DHL Expressbrief','First Seller Profile SHIPPING');
    is(scalar @{$ahSellerProfiles},3,'One Seller Profile SHIPPING');
}

sub test_return_policy_seller_profile {
    my $self = shift;

    my $ahSellerProfiles = DE_EPAGES::Ebay::API::Object::EbayShopEnvironment->filterSellerProfiles(EBAY_GET_SELLER_PROFILE_RESPONSE,'RETURN_POLICY');

    is($ahSellerProfiles->[0]->{'ProfileName'},'Der Artikel kann zurückgegeben werden','First Seller Profile RETURN_POLICY');
    is(scalar @{$ahSellerProfiles},2,'One Seller Profile RETURN_POLICY');
}


sub test_default_payment_seller_profile {
    my $self = shift;

    my $hDefaultProfile = DE_EPAGES::Ebay::API::Object::EbayShopEnvironment->filterSellerProfilesByDefault(EBAY_GET_SELLER_PROFILE_RESPONSE,'PAYMENT');
    is($hDefaultProfile->{'ProfileID'}, "97160275015", 'Default Payment Profile');

}

sub test_default_shipping_seller_profile {
    my $self = shift;

    my $hDefaultProfile = DE_EPAGES::Ebay::API::Object::EbayShopEnvironment->filterSellerProfilesByDefault(EBAY_GET_SELLER_PROFILE_RESPONSE,'SHIPPING');
    is($hDefaultProfile->{'ProfileID'}, "88349570015", 'Default Shipping Profile');

}

sub test_default_return_seller_profile {
    my $self = shift;

    my $hDefaultProfile = DE_EPAGES::Ebay::API::Object::EbayShopEnvironment->filterSellerProfilesByDefault(EBAY_GET_SELLER_PROFILE_RESPONSE,'RETURN_POLICY');
    is($hDefaultProfile->{'ProfileID'}, "88247904015", 'Default Return Policy Profile');

}

__PACKAGE__->runScript;

1;
