#========================================================================================
# package      DE_EPAGES::PayPalPlus::t::unit::PatchPayment_Service
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  unit tests for PatchPayment::Service
#========================================================================================
package DE_EPAGES::PayPalPlus::t::unit::PatchPayment_Service;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::PayPalPlus::API::Webservice::PatchPayment::Service;
use DE_EPAGES::PayPalPlus::API::Webservice::PatchPayment::RequestDTO;
use DE_EPAGES::PayPalPlus::API::Webservice::PatchPayment::RequestRepository;
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use DE_EPAGES::Test::Mock::Mockify qw (WasCalled);

use URI;
use URI::QueryParam;

use DE_EPAGES::Core::API::Error qw ( Error );

use Test::More;
use Test::Exception;
use strict;

sub test {
    my $self = shift;

    $self->test_ExpectedErrorCollectData();
    $self->test_UnexpectedErrorCollectData();

    $self->test_FailedRequest();
    $self->test_SuccessfulRequest();

    done_testing();
}
sub test_ExpectedErrorCollectData {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Basket = $self->_createBasket();

    my $PatchPaymentService = $self->_buildPatchPaymentServiceWithExpectedError();
    is($PatchPaymentService->doRequest($Basket), 0,"$SubTestName - Test if the request was failed");
    is($PatchPaymentService->getErrorCode(), 'WRONG_CLASS', "$SubTestName - Test if a error was throw after the request");
    is($PatchPaymentService->getErrorMessage(), 'Basket not valid for creating the request', "$SubTestName - Test if a error message was setted");
    ok(WasCalled($Basket, 'recalculate'), "$SubTestName - Test is recalculate was called");
}
#----------------------------------------------------------------------------------------
sub test_UnexpectedErrorCollectData {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Basket = $self->_createBasket();

    my $PatchPaymentService = $self->_buildPatchPaymentServiceWithUnexpectedError();
    throws_ok( sub { $PatchPaymentService->doRequest($Basket) },
                   qr/Test_UnexpectedError/,
                   "$SubTestName - Test if the request was failed"
         );
    ok(WasCalled($Basket, 'recalculate'), "$SubTestName - Test is recalculate was called");
}
#----------------------------------------------------------------------------------------
sub test_FailedRequest {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Basket = $self->_createBasket();

    my $PatchPaymentService = $self->_buildPatchPaymentServiceNotSuccesfulRequest();
    is($PatchPaymentService->doRequest($Basket), 0,"$SubTestName - Test if the request was not successful");
    is($PatchPaymentService->getErrorCode(), 'ErrorCode', "$SubTestName - Test if error was throw after the request");
    is($PatchPaymentService->getErrorMessage(), 'ErrorMessage', "$SubTestName - Test if error message was setted");
    ok(WasCalled($Basket, 'recalculate'), "$SubTestName - Test is recalculate was called");
}
#----------------------------------------------------------------------------------------
sub test_SuccessfulRequest {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Basket = $self->_createBasket();
    my $PatchPaymentService = $self->_buildPatchPaymentService();

    is($PatchPaymentService->doRequest($Basket), 1, "$SubTestName - Test if the request was successful");
    is($PatchPaymentService->getErrorCode(), undef, "$SubTestName - Test if no error was throw after the request");
    is($PatchPaymentService->getErrorMessage(), undef, "$SubTestName - Test if no error message was setted");
    ok(WasCalled($Basket, 'recalculate'), "$SubTestName - Test is recalculate was called");
}
#----------------------------------------------------------------------------------------
#  Helpers
#----------------------------------------------------------------------------------------
sub _buildPatchPaymentService{
    my $self = shift;

    my $WasSuccessfulRequest = 1;
    my $hTestSettings = {
        'RestService' => $self->_createRestService($WasSuccessfulRequest),
        'RequestRepo' => $self->_createRequestRepository(),
    };
    return $self->_createPatchPaymentService( $hTestSettings );
}
#----------------------------------------------------------------------------------------
sub _buildPatchPaymentServiceNotSuccesfulRequest{
    my $self = shift;

    my $WasSuccessfulRequest = 0;
    my $hTestSettings = {
        'RestService' => $self->_createRestService($WasSuccessfulRequest),
        'RequestRepo' => $self->_createRequestRepository(),
    };
    return $self->_createPatchPaymentService( $hTestSettings );
}
#----------------------------------------------------------------------------------------
sub _buildPatchPaymentServiceWithExpectedError{
    my $self = shift;
    my $WasSuccessfulRequest = 0;
    my $hTestSettings = {
        'RestService' => $self->_createRestService($WasSuccessfulRequest),
        'RequestRepo' => $self->_createRequestRepository_WithError('WRONG_CLASS'),
    };
    return $self->_createPatchPaymentService( $hTestSettings );
}
#----------------------------------------------------------------------------------------
sub _buildPatchPaymentServiceWithUnexpectedError{
    my $self = shift;
    my $WasSuccessfulRequest = 0;
    my $hTestSettings = {
        'RestService' => $self->_createRestService($WasSuccessfulRequest),
        'RequestRepo' => $self->_createRequestRepository_WithError('Test_UnexpectedError'),
    };
    return $self->_createPatchPaymentService( $hTestSettings );
}
#----------------------------------------------------------------------------------------
sub _createPatchPaymentService {
    my $self = shift;
    my ( $hTestSettings ) = @_;
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new(
                   'DE_EPAGES::PayPalPlus::API::Webservice::PatchPayment::Service',
                   []
              );
    $Mockify->addMockWithReturnValue('_createRequestRepository', $hTestSettings->{'RequestRepo'});
    $Mockify->addMockWithReturnValueAndParameterCheck('_LogError', undef, [{'object' => 'DE_EPAGES::Core::API::Error'}]);
    $Mockify->addMockWithReturnValueAndParameterCheck('_createRestService', $hTestSettings->{'RestService'}, [{'object' => 'DE_EPAGES::Order::API::Object::Basket'}]);
    $Mockify->addMockWithReturnValue('_createRestURLService', $self->_createRestURLService());

    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createRequestRepository{
    my $self = shift;
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new(
                   'DE_EPAGES::PayPalPlus::API::Webservice::PatchPayment::RequestRepository',
                   []
              );
    $Mockify->addMockWithReturnValueAndParameterCheck('collectData', 1, [{'object' => 'DE_EPAGES::Order::API::Object::Basket'}]);
    $Mockify->addMockWithReturnValue('getRequestDTO', $self->_createRequestDTO());
    $Mockify->addMockWithReturnValue('getCredentialDTO', $self->_createCredentialDTO());
    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createRequestRepository_WithError{
    my $self = shift;
    my ( $ErrorMessage ) = @_;
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new(
                   'DE_EPAGES::PayPalPlus::API::Webservice::PatchPayment::RequestRepository',
                   []
              );
    $Mockify->addMock('collectData', sub {
        Error($ErrorMessage);
    });
    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createRequestDTO {
    my $self = shift;
    my $RequestDTO = DE_EPAGES::PayPalPlus::API::Webservice::PatchPayment::RequestDTO->new();
    $RequestDTO->paymentId('DummyPaymentId');
    return $RequestDTO;
}
#----------------------------------------------------------------------------------------
sub _createCredentialDTO {
    my $self = shift;
    my $RequestDTO = DE_EPAGES::PayPalPlus::API::Webservice::Base::CredentialDTO->new();
    $RequestDTO->isInTestMode(1);
    $RequestDTO->merchantClientId('MyDummyMerchantClientID');
    $RequestDTO->providerClientSecret('MyDummyProviderClientSecret');
    $RequestDTO->providerClientId('MyDummyProviderClientID');
    $RequestDTO->payPalPartnerAttributionId('MyAttributionId');
    return $RequestDTO;
}
#----------------------------------------------------------------------------------------
sub _createRestService {
    my $self = shift;
    my ($WasSuccessfulRequest) = @_;
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new(
                   'DE_EPAGES::PayPalPlus::API::Webservice::RestService',
                   []
              );
    $Mockify->addMockWithReturnValueAndParameterCheck('post', $WasSuccessfulRequest, [
        {'string'=>'http://myDummyURL.info'},
        {'hashref' => {
          'isTestTransaction' => 'true',
          'merchantClientId' => 'MyDummyMerchantClientID',
          'providerClientSecret' => 'MyDummyProviderClientSecret',
          'providerClientId' => 'MyDummyProviderClientID',
          'payPalPartnerAttributionId' => 'MyAttributionId',
        }},
        {'hashref' => {
          'shippingAddress' => undef,
          'billingAddress' => undef,
          'basketCurrency' => undef,
          'subTotalPrice' => undef,
          'basketPrice' => undef,
          'taxPrice' => undef,
          'shippingPrice' => undef,
          'discountPrice' => undef,
          'handlingFeePrice' => undef,
          'paymentId' => 'DummyPaymentId'
        }}
    ]);
    $Mockify->addMockWithReturnValue('getResponse', {'dummy'=>'hash'});
    $Mockify->addMockWithReturnValue('getErrorCode', 'ErrorCode');
    $Mockify->addMockWithReturnValue('getErrorMessage', 'ErrorMessage');
    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createRestURLService {
    my $self = shift;

    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new(
                   'DE_EPAGES::PayPalPlus::API::Webservice::RestURLService',
                   []
              );

    $Mockify->addMockWithReturnValueAndParameterCheck('buildEpagesJRestUrl', 'http://myDummyURL.info', [
        {'string' => 'payments/paypalplus/patch'},
        {'hashref' => {} },
    ]);
    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createBasket {
    my $self = shift;
    my $MockifyBasket = DE_EPAGES::Test::Mock::MockifyEpagesObject->new( 'DE_EPAGES::Order::API::Object::Basket', {
        'Alias' => 'Basket',
    });
    $MockifyBasket->addMockWithReturnValue('recalculate', undef);
    return $MockifyBasket->getMockObject();

}
__PACKAGE__->runScript();
