#========================================================================================
# package      DE_EPAGES::Payment::API::Attributes::PaymentMethod_Ext
# state        private
# description  Attribute interface for PaymentMethod.
#========================================================================================
package DE_EPAGES::Payment::API::Attributes::PaymentMethod_Ext;
use base DE_EPAGES::Object::API::BaseAttribute;

use strict;
use DE_EPAGES::Shop::API::Constants qw (TAX_MODEL_GROSS);
use DE_EPAGES::Object::API::Factory qw (LoadObject);
use DE_EPAGES::Payment::API::Shop qw (GetShopPaymentLogos);
use DE_EPAGES::Payment::API::Table::PaymentMethodCustomerGroup qw ( InsertPaymentMethodCustomerGroup
                                                                    DeletePaymentMethodCustomerGroup
                                                                    GetPKeyPaymentMethodCustomerGroupsByPaymentMethodID
                                                                    GetInfoPaymentMethodCustomerGroupsByPaymentMethodID );
use DE_EPAGES::Payment::API::Table::PaymentMethodPriceLimit qw(GetInfoPaymentMethodPriceLimitsByPaymentMethodID);
use DE_EPAGES::Payment::API::Table::PaymentMethodDiscount qw ( GetInfoPaymentMethodDiscountsByPaymentMethodID );

sub getAttributes {
    shift;
    my ($Object, $aNames) = @_;

    my %Values;
    foreach my $Name ( @$aNames ) {
        if ($Name eq 'UsableAtStorefront' ) {
            my $Shop = $Object->getSite();
            my $Usable = 1;
            foreach my $CurrencyID (map {$_->{'CurrencyID'} } grep { $_->{'IsActivated'} == 1 } @{$Shop->get('Currencies')}) {
                $Usable &&= $Object->usableAtStorefront({ 'TaxModel' => TAX_MODEL_GROSS, CurrencyID => $CurrencyID});
                last unless $Usable;
            }
            $Values{$Name} = $Usable;
        }
        elsif ($Name eq 'CustomerGroups' ) {
            $Values{$Name} = [ map { LoadObject($_->{'CustomerGroupID'} ) } @{GetInfoPaymentMethodCustomerGroupsByPaymentMethodID($Object->id)} ] ;
        }
        elsif( $Name eq 'Logos' ) {
            $Values{$Name} = GetShopPaymentLogos( $Object->getSite(), $Object->get('PaymentType'));
        }
        elsif( $Name eq 'PriceLimits' ) {
                $Values{$Name} = _GetPrice($Object);
        }
        elsif( $Name eq 'HasPriceLimit' ) {
                $Values{$Name} = scalar @{_GetPrice($Object)} ? 1:0;
        }
        elsif( $Name eq 'Discounts' ) {
                $Values{$Name} = _GetDiscountPrice($Object);
        }
        elsif( $Name eq 'ProviderName' ) {
                $Values{$Name} = $Object->getProviderName();
        }
        elsif( $Name eq 'PaymentMethodName' ) {
                $Values{$Name} = $Object->getPaymentMethodName();
        }
        elsif( $Name eq 'CanBeDefaultPaymentMethod' ) {
                $Values{$Name} = $Object->canBeDefaultPayment();
        }
    }
    return \%Values;
}

sub setAttributes {
    shift;
    my ($Object, $hUpdate) = @_;

    foreach my $Name ( keys %$hUpdate ) {
        if ( $Name eq 'CustomerGroups' ) {
            # test the object type of each loop item
            my $aCustomerGroups = $hUpdate->{$Name};

            # delete all loop items
            my $aKeys = GetPKeyPaymentMethodCustomerGroupsByPaymentMethodID( $Object->id );
            DeletePaymentMethodCustomerGroup( $_ ) foreach @$aKeys;

            #insert new items
            foreach my $CustomerGroup ( @$aCustomerGroups ) {
                InsertPaymentMethodCustomerGroup( {
                    PaymentMethodID => $Object->id,
                    CustomerGroupID => $CustomerGroup->id,
                } );
            }
        }
    }
    return;
}

sub _GetPrice {
    my ($Object, $Attribute) = @_;
    return [
        sort { $a->{'CurrencyID'} cmp $b->{'CurrencyID'} }
        @{GetInfoPaymentMethodPriceLimitsByPaymentMethodID($Object->id)}
    ];
}

sub _GetDiscountPrice {
    my ($Object, $Attribute) = @_;
    return [
        sort { $a->{'CurrencyID'} cmp $b->{'CurrencyID'} }
        @{GetInfoPaymentMethodDiscountsByPaymentMethodID($Object->id)}
    ];
}


1;
