#========================================================================================
# package      DE_EPAGES::Payment::API::Attributes::Shop
# state        private
# description  Attribute interface for payment Shop.
#========================================================================================
package DE_EPAGES::Payment::API::Attributes::Shop;
use base DE_EPAGES::Object::API::BaseAttribute;

use strict;
use DE_EPAGES::Object::API::Factory qw (LoadClassByAlias LoadObject LoadRootObject);
##no critic (RequireCorrectImports)
use DE_EPAGES::Payment::API::XML::PaymentImportHandler;
use DE_EPAGES::Payment::API::XML::PaymentExportDriver;
use DE_EPAGES::Payment::API::XML::PaymentDeleteHandler;
##use critic

sub getAttributes {
    shift;
    my ($Shop, $aNames) = @_;
    my $hInfo = {};

    foreach my $Name ( @$aNames ) {
        if ($Name eq 'PaymentMethods') {
            $hInfo->{$Name} = [ sort {$a->get('Position') <=> $b->get('Position') } @{LoadClassByAlias('PaymentMethod')->getObjects('ByShopID', [$Shop->id])}];
        } elsif ($Name eq 'PaymentMethodsWithoutShipping') {
            my @PaymentMethods = grep { $_->get('UsableAtStorefront') } @{LoadClassByAlias('PaymentMethod')->getObjects('ByShopID', [$Shop->id])};
            $hInfo->{$Name} = [grep { $_->get('WorksWithoutShipping') } @PaymentMethods];
        }  elsif ($Name eq 'PaymentGroups') {
            $hInfo->{$Name} = _GetPaymentGroups($Shop);
        } elsif ($Name eq 'InterestRateMatrices') {
            $hInfo->{$Name} = LoadClassByAlias('InterestRateMatrix')->getObjects('ByShopID',[ $Shop->id ]);
        }
    }
    return $hInfo;
}

sub deleteObject {
    shift;
    my ($Object) = @_;
    $Object->child('PaymentMethods')->delete if $Object->existsChild('PaymentMethods');
    $Object->child('InterestRateMatrices')->delete if $Object->existsChild('InterestRateMatrices');
    return;
}

#========================================================================================
# function     exportXMLElements
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Package->exportXMLElements($Driver, $Object, $aNames, $hAttributes);
#----------------------------------------------------------------------------------------
# description  Adds sub elements of object for xml export.
#----------------------------------------------------------------------------------------
# input        $Driver | xml export driver | object
# input        $Object | object to export | object
# input        $aNames | attribute names | ref.array.string
# input        $hAttributes | imported attributes | ref.hash
#========================================================================================
sub exportXMLElements {
    my $self = shift;
    my ($Driver, $Object, $aNames, $hAttributes) = @_;

    foreach my $PaymentMethod (@{ $Object->get('PaymentMethods') } ) {
        foreach my $PaymentLogo (@{ $PaymentMethod->get('Logos') }) {
            if ($PaymentLogo->{'IsVisible'}) {
                my $PaymentTypeLogo = LoadObject($PaymentLogo->{'PaymentTypeLogo'}->id);
                if ($Driver->exportLevel == $PaymentTypeLogo->class->get('ExportLevel')) {
                    $Driver->addElement('ShopPaymentLogo', {'PaymentTypeLogo' => $PaymentTypeLogo->get('Path')});
                }
            }
        }
    }
    return;
}

sub _GetPaymentGroups() {
    my ($Shop) = @_;

    my $System = LoadRootObject();
    my $aPaymentGroups = $System->get('PaymentGroups');
    my @AvailablePaymentGroups = ();
    foreach my $PaymentGroup (@{$aPaymentGroups}){
        if($PaymentGroup->isUsable($Shop)) {
            push(@AvailablePaymentGroups, $PaymentGroup);
        }
    }

    my @SortedAvailablePaymentGroups = sort {$a->get('Position') <=> $b->get('Position') } @AvailablePaymentGroups;
    return \@SortedAvailablePaymentGroups;
}

1;
