#========================================================================================
# package      DE_EPAGES::Payment::t::unit::PaymentGroup_Attributes
# base         DE_EPAGES::Test::API::UnitTest::Test
#----------------------------------------------------------------------------------------
# description  unit test for API::Attributes::PaymentGroup.pm
#========================================================================================
package DE_EPAGES::Payment::t::unit::PaymentGroup;
use base DE_EPAGES::Test::API::UnitTest::Test;

use DE_EPAGES::Payment::API::Attributes::PaymentGroup;
use Test::More;
use strict;

sub test {
    my $self = shift;

    $self->test_getAttributes_with_specified_payment_group_name();
    $self->test_getAttributes_without_specified_payment_group_name();

    done_testing();
}

sub test_getAttributes_with_specified_payment_group_name {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    # GIVEN
    my $PaymentGroup = $self->mockFactory->build('DE_EPAGES::Payment::API::Object::PaymentGroup', {
        'NameOrAlias' => 'Standard',
        'PaymentGroupName' => 'Manuel Paymentmethods'
    })->getMockObject();

    # WHEN
    my $hResult = DE_EPAGES::Payment::API::Attributes::PaymentGroup
        ->getAttributes($PaymentGroup, ['PaymentGroupDisplayName']);

    # THEN
    is($hResult->{'PaymentGroupDisplayName'}, 'Manuel Paymentmethods',
        "$SubTestName - ensure PaymentGroupName is used when specified.");

    return;
}

sub test_getAttributes_without_specified_payment_group_name {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    # GIVEN
    my $PaymentGroup = $self->mockFactory->build('DE_EPAGES::Payment::API::Object::PaymentGroup', {
        'NameOrAlias' => 'Standard',
        'PaymentGroupName' => undef
    })->getMockObject();

    # WHEN
    my $hResult = DE_EPAGES::Payment::API::Attributes::PaymentGroup
        ->getAttributes($PaymentGroup, ['PaymentGroupDisplayName']);

    # THEN
    is($hResult->{'PaymentGroupDisplayName'}, 'Standard',
        "$SubTestName - ensure NameOrAlias is used as fallback in case PaymentGroupName isn't specified.");

    return;
}

__PACKAGE__->runScript();