#========================================================================================
# package      DE_EPAGES::Payment::t::unit::PaymentMethod
# base         DE_EPAGES::Core::API::Test
#----------------------------------------------------------------------------------------
# description  unit test for PaymentMethod
#========================================================================================
package DE_EPAGES::Payment::t::unit::PaymentMethod;
use base DE_EPAGES::Core::API::Test;
use Test::More;
use DE_EPAGES::Test::Mock::Mockery;
use DE_EPAGES::Test::Mock::Mockify;
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use strict;

use DE_EPAGES::Payment::API::Constants qw( CLASSICCHECKOUT MULTISTEPCHECKOUT );

sub test {
    my $self = shift;
    $self->test_canBeDefaultPayment_CanDoClassicCheckout();
    $self->test_canBeDefaultPayment_CanDoMultiStepCheckout();
    $self->test_canBeDefaultPayment_CanNotDoClassicCheckout();
    $self->test_canBeDefaultPayment_CanNotDoMultiStepCheckout();

    $self->test_canBeDefaultPayment_CanDoClassicCheckout_CanNotBeDefaultPayment();
    $self->test_canBeDefaultPayment_CanDoMultiStepCheckout_CanNotBeDefaultPayment();
    $self->test_canBeDefaultPayment_CanNotDoClassicCheckout_CanNotBeDefaultPayment();
    $self->test_canBeDefaultPayment_CanNotDoMultiStepCheckout_CanNotBeDefaultPayment();

    done_testing();
}
#----------------------------------------------------------------------------------------
sub test_canBeDefaultPayment_CanDoClassicCheckout {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $Mockery = $self->_createMocks({
        'OrderProcess' => CLASSICCHECKOUT,
        'CanBeDefaultPayment' => 1,
    });
    
    my $Result = $Mockery->get('PaymentMethodCanDoCheckout')->canBeDefaultPayment();
    is($Result, 1, "$SubTestName - test if the payment can handle classic checkout");
}
#----------------------------------------------------------------------------------------
sub test_canBeDefaultPayment_CanDoMultiStepCheckout {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $Mockery = $self->_createMocks({
        'OrderProcess' => MULTISTEPCHECKOUT,
        'CanBeDefaultPayment' => 1,
    });
    
    my $Result = $Mockery->get('PaymentMethodCanDoCheckout')->canBeDefaultPayment();
    is($Result, 1, "$SubTestName - test if the payment can handle multistep checkout");
}
#----------------------------------------------------------------------------------------
sub test_canBeDefaultPayment_CanNotDoClassicCheckout {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $Mockery = $self->_createMocks({
        'OrderProcess' => CLASSICCHECKOUT,
        'CanBeDefaultPayment' => 1,
    });
    
    my $Result = $Mockery->get('PaymentMethodCanNotDoCheckout')->canBeDefaultPayment();
    is($Result, 0, "$SubTestName - test if the payment can not handle classic checkout");
}
#----------------------------------------------------------------------------------------
sub test_canBeDefaultPayment_CanNotDoMultiStepCheckout {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $Mockery = $self->_createMocks({
        'OrderProcess' => MULTISTEPCHECKOUT,
        'CanBeDefaultPayment' => 1,
    });
    
    my $Result = $Mockery->get('PaymentMethodCanNotDoCheckout')->canBeDefaultPayment();
    is($Result, 0, "$SubTestName - test if the payment can not handle multistep checkout");
}
#----------------------------------------------------------------------------------------
sub test_canBeDefaultPayment_CanDoClassicCheckout_CanNotBeDefaultPayment {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $Mockery = $self->_createMocks({
        'OrderProcess' => CLASSICCHECKOUT,
        'CanBeDefaultPayment' => 0,
    });
    
    my $Result = $Mockery->get('PaymentMethodCanDoCheckout')->canBeDefaultPayment();
    is($Result, 0, "$SubTestName - test if the payment can handle classic checkout but can not be selected as default payment");
}
#----------------------------------------------------------------------------------------
sub test_canBeDefaultPayment_CanDoMultiStepCheckout_CanNotBeDefaultPayment {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $Mockery = $self->_createMocks({
        'OrderProcess' => MULTISTEPCHECKOUT,
        'CanBeDefaultPayment' => 0,
    });
    
    my $Result = $Mockery->get('PaymentMethodCanDoCheckout')->canBeDefaultPayment();
    is($Result, 0, "$SubTestName - test if the payment can handle multistep checkout but can not be selected as default payment");
}
#----------------------------------------------------------------------------------------
sub test_canBeDefaultPayment_CanNotDoClassicCheckout_CanNotBeDefaultPayment {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $Mockery = $self->_createMocks({
        'OrderProcess' => CLASSICCHECKOUT,
        'CanBeDefaultPayment' => 0,
    });
    
    my $Result = $Mockery->get('PaymentMethodCanNotDoCheckout')->canBeDefaultPayment();
    is($Result, 0, "$SubTestName - test if the payment can not handle classic checkout and can not be selected as default payment");
}
#----------------------------------------------------------------------------------------
sub test_canBeDefaultPayment_CanNotDoMultiStepCheckout_CanNotBeDefaultPayment {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $Mockery = $self->_createMocks({
        'OrderProcess' => MULTISTEPCHECKOUT,
        'CanBeDefaultPayment' => 0,
    });
    
    my $Result = $Mockery->get('PaymentMethodCanNotDoCheckout')->canBeDefaultPayment();
    is($Result, 0, "$SubTestName - test if the payment can not handle multistep checkout and can not be selected as default payment");
}
#----------------------------------------------------------------------------------------
# helper
#----------------------------------------------------------------------------------------
sub _createMocks {
    my $self = shift;
    my ($hSettings) = @_;
    my $Mockery = DE_EPAGES::Test::Mock::Mockery->new();

    $Mockery->register('Shop',[], sub {
        my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
            'DE_EPAGES::Shop::API::Object::Shop',
            {
                'OrderProcess' => $hSettings->{'OrderProcess'},
            }
        );

        return $Mockify->getMockObject();
    });
    $Mockery->register('PaymentMethodCanDoCheckout',['Shop','PaymentTypeCanDoCheckout'], sub {
        my ($Shop, $PaymentType) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
            'DE_EPAGES::Payment::API::Object::PaymentMethod',
            {
                'Shop' => $Shop,
                'PaymentType' => $PaymentType,
            }
        );

        return $Mockify->getMockObject();
    });
    $Mockery->register('PaymentTypeCanDoCheckout',[], sub {
        my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
            'DE_EPAGES::Payment::API::Object::PaymentType',
            {
                'CanDoClassicCheckout' => 1,
                'CanDoMultiStepCheckout' => 1,
                'CanBeDefaultPayment' => $hSettings->{'CanBeDefaultPayment'},
            }
        );

        return $Mockify->getMockObject();
    });
    $Mockery->register('PaymentMethodCanNotDoCheckout',['Shop','PaymentTypeCanNotDoCheckout'], sub {
        my ($Shop, $PaymentType) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
            'DE_EPAGES::Payment::API::Object::PaymentMethod',
            {
                'Shop' => $Shop,
                'PaymentType' => $PaymentType,
            }
        );

        return $Mockify->getMockObject();
    });
    $Mockery->register('PaymentTypeCanNotDoCheckout',[], sub {
        my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
            'DE_EPAGES::Payment::API::Object::PaymentType',
            {
                'CanDoClassicCheckout' => 0,
                'CanDoMultiStepCheckout' => 0,
                'CanBeDefaultPayment' => $hSettings->{'CanBeDefaultPayment'},
            }
        );

        return $Mockify->getMockObject();
    });

    return $Mockery->assemble();
}

__PACKAGE__->runScript();