#========================================================================================
# package      DE_EPAGES::Payment::t::unit::PaymentMethod_getPaymentMethodName
# base         DE_EPAGES::Test::API::UnitTest::Test
#----------------------------------------------------------------------------------------
# description  unit test for DE_EPAGES::Payment::API::Object::PaymentMethod_getPaymentMethodName
#========================================================================================
package DE_EPAGES::Payment::t::unit::PaymentMethod_getPaymentMethodName;
use base DE_EPAGES::Test::API::UnitTest::Test;
use DE_EPAGES::Test::Mock::Mockify ;
use Test::More;

use strict;

sub test {
    my $self = shift;

    $self->test_getProviderName_StandardPayment_NameAsPaymentMethodName_notExist();
    $self->test_getProviderName_StandardPayment_NameAsPaymentMethodName_exist_and_false();
    $self->test_getProviderName_StandardPayment_NameAsPaymentMethodName_exist_and_true();

    $self->test_getProviderName_ExternalPayment_NameAsPaymentMethodName_notExist();
    $self->test_getProviderName_ExternalPayment_NameAsPaymentMethodName_exist_and_false();
    $self->test_getProviderName_ExternalPayment_NameAsPaymentMethodName_exist_and_true();

    done_testing();
}
#----------------------------------------------------------------------------------------
sub test_getProviderName_StandardPayment_NameAsPaymentMethodName_notExist {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $PaymentMethod = $self->_createSUT({
        'Exists_NameAsPaymentMethodName' => 0,
        'NameAsPaymentMethodName' => 0,
        'PaymentMethodClass' => $self->_createPaymentMethodClass('DE_EPAGES::PaymentTypes::API::Object::PaymentMethodFree'),
    });
    my $LanguageId = 1;
    my $ProviderName = $PaymentMethod->getPaymentMethodName($LanguageId);

    is($ProviderName, 'NameOrAliasInGerman', "$SubTestName - tests if the standard payment name is name or alias.");
}
#----------------------------------------------------------------------------------------
sub test_getProviderName_StandardPayment_NameAsPaymentMethodName_exist_and_false {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $PaymentMethod = $self->_createSUT({
        'Exists_NameAsPaymentMethodName' => 1,
        'NameAsPaymentMethodName' => 0,
        'PaymentMethodClass' => $self->_createPaymentMethodClass('DE_EPAGES::PaymentTypes::API::Object::PaymentMethodFree'),
    });
    my $LanguageId = 1;
    my $ProviderName = $PaymentMethod->getPaymentMethodName($LanguageId);

    is($ProviderName, 'NameOrAliasInGerman', "$SubTestName - tests if the standard payment name is name or alias.");
}
#----------------------------------------------------------------------------------------
sub test_getProviderName_StandardPayment_NameAsPaymentMethodName_exist_and_true {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $PaymentMethod = $self->_createSUT({
        'Exists_NameAsPaymentMethodName' => 1,
        'NameAsPaymentMethodName' => 1,
        'PaymentMethodClass' => $self->_createPaymentMethodClass('DE_EPAGES::PaymentTypes::API::Object::PaymentMethodFree'),
    });
    my $LanguageId = 1;
    my $ProviderName = $PaymentMethod->getPaymentMethodName($LanguageId);

    is($ProviderName, 'NameOrAliasInGerman', "$SubTestName - tests if the standard payment name is name or alias.");
}
#----------------------------------------------------------------------------------------
sub test_getProviderName_ExternalPayment_NameAsPaymentMethodName_notExist {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $PaymentMethod = $self->_createSUT({
        'Exists_NameAsPaymentMethodName' => 0,
        'NameAsPaymentMethodName' => 0,
        'PaymentMethodClass' => $self->_createPaymentMethodClass('DE_EPAGES::Mollie::API::Object::PaymentMethodMollie'),
    });
    my $LanguageId = 1;
    my $ProviderName = $PaymentMethod->getPaymentMethodName($LanguageId);

    is($ProviderName, 'PaymentMethodAlias', "$SubTestName - tests if the payment type alias is used.");
}
#----------------------------------------------------------------------------------------
sub test_getProviderName_ExternalPayment_NameAsPaymentMethodName_exist_and_false {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $PaymentMethod = $self->_createSUT({
        'Exists_NameAsPaymentMethodName' => 1,
        'NameAsPaymentMethodName' => 0,
        'PaymentMethodClass' => $self->_createPaymentMethodClass('DE_EPAGES::Mollie::API::Object::PaymentMethodMollie'),
    });
    my $LanguageId = 1;
    my $ProviderName = $PaymentMethod->getPaymentMethodName($LanguageId);

    is($ProviderName, 'PaymentMethodAlias', "$SubTestName - tests if the payment type alias is used.");
}
#----------------------------------------------------------------------------------------
sub test_getProviderName_ExternalPayment_NameAsPaymentMethodName_exist_and_true {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $PaymentMethod = $self->_createSUT({
        'Exists_NameAsPaymentMethodName' => 1,
        'NameAsPaymentMethodName' => 1,
        'PaymentMethodClass' => $self->_createPaymentMethodClass('DE_EPAGES::Mollie::API::Object::PaymentMethodMollie'),
    });
    my $LanguageId = 1;
    my $ProviderName = $PaymentMethod->getPaymentMethodName($LanguageId);

    is($ProviderName, 'NameOrAliasInGerman', "$SubTestName - tests if the german field of provider is used.");
}
#----------------------------------------------------------------------------------------
sub _createSUT {
    my $self = shift;
    my ( $hSetup ) = @_;

    my $hAttributes = {
        'Alias' => 'PaymentMethodAlias',
        'NameOrAlias' => 'NameOrAliasInGerman',
        'PaymentType' => $self->_createPaymentType($hSetup),
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Payment::API::Object::PaymentMethod',
        $hAttributes
    );
    $Mockify->mock('class', $hSetup->{'PaymentMethodClass'});
    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createPaymentType {
    my $self = shift;
    my ($hSetup) = @_;
    my $hAttributes = {
        'Alias' => 'PaymentTypeAlias',
        'NameAsPaymentMethodName' => $hSetup->{'NameAsPaymentMethodName'},
    };
    my $DefaultLanguageId = 1;
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Payment::API::Object::PaymentType',
        $hAttributes,
        $DefaultLanguageId
    );
    $Mockify->mock('class', $self->_createPaymentTypeClass($hSetup->{'Exists_NameAsPaymentMethodName'}));
    $Mockify->addLanguageDependentAttribute('NameOrAlias', {
        1 => 'NameOrAliasInGerman'
    });

    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createPaymentMethodClass {
    my $self = shift;
    my ($ClassName) = @_;
    my $hAttributes = {
        'Package' => $ClassName,
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
                   'DE_EPAGES::Object::API::Object::Class',
                   $hAttributes
              );
    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createPaymentTypeClass {
    my $self = shift;
    my ($ExistsAttribute) = @_;
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
                   'DE_EPAGES::Object::API::Object::Class',
                   {}
              );
    $Mockify->mock('existsAttribute', $ExistsAttribute, [{'string'=>'NameAsPaymentMethodName'}]);
    return $Mockify->getMockObject();
}
__PACKAGE__->runScript();