#========================================================================================
# package      DE_EPAGES::Payment::t::unit::PaymentMethod_getProviderName
# base         DE_EPAGES::Test::API::UnitTest::Test
#----------------------------------------------------------------------------------------
# description  unit test for DE_EPAGES::Payment::API::Object::PaymentMethod
#========================================================================================
package DE_EPAGES::Payment::t::unit::PaymentMethod_getProviderName;
use base DE_EPAGES::Test::API::UnitTest::Test;
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use Test::More;

use strict;

sub test {
    my $self = shift;

    $self->test_getProviderName_ProviderDefined();
    $self->test_getProviderName_ProviderUndefined();
    $self->test_getProviderName_ProviderUndefined_NameOrAliasUndefined();

    done_testing();
}
#----------------------------------------------------------------------------------------
sub test_getProviderName_ProviderDefined {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $PaymentMethod = $self->_createSUT();
    my $LanguageId = 1;
    my $ProviderName = $PaymentMethod->getProviderName($LanguageId);

    is($ProviderName, 'ProviderNameInGerman', "$SubTestName - tests if the german field of provider is used.");
}

#----------------------------------------------------------------------------------------
sub test_getProviderName_ProviderUndefined {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $PaymentMethod = $self->_createSUT();
    my $LanguageId= 2;
    my $ProviderName = $PaymentMethod->getProviderName($LanguageId);

    is($ProviderName, 'NameOrAliasInEnglish', "$SubTestName - tests if the english fall back of payment type is used.");
}
#----------------------------------------------------------------------------------------
sub test_getProviderName_ProviderUndefined_NameOrAliasUndefined {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $PaymentMethod = $self->_createSUT();
    my $LanguageId= 3;
    my $ProviderName = $PaymentMethod->getProviderName($LanguageId);

    is($ProviderName, undef, "$SubTestName - tests if both are not defined.");
}
#----------------------------------------------------------------------------------------
# helpers
#----------------------------------------------------------------------------------------
sub _createSUT {
    my $self = shift;

    my $hAttributes = {
        'Alias' => 'MyShop',
        'PaymentType' => $self->_createPaymentType()
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Payment::API::Object::PaymentMethod',
        $hAttributes
    );

    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createPaymentType {
    my $self = shift;

    my $hAttributes = {
        'Alias' => 'MyShop',
    };
    my $DefaultLanguageId = 1;
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Payment::API::Object::PaymentType',
        $hAttributes,
        $DefaultLanguageId
    );
    $Mockify->addLanguageDependentAttribute('Provider', {
        1 => 'ProviderNameInGerman'
    });
    $Mockify->addLanguageDependentAttribute('NameOrAlias', {
        2 => 'NameOrAliasInEnglish'
    });

    return $Mockify->getMockObject();
}

__PACKAGE__->runScript();