#========================================================================================
# package      DE_EPAGES::Payment::t::unit::PaymentType_canCreateAdditionalPaymentMethod
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  unit test for method canCreateAdditionalPaymentMethod
#               in package: DE_EPAGES::Payment::t::unit::PaymentType_canCreateAdditionalPaymentMethod
#========================================================================================
package DE_EPAGES::Payment::t::unit::PaymentType_canCreateAdditionalPaymentMethod;
use base DE_EPAGES::Core::API::Test;
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use Test::More;
use strict;

sub test {
    my $self = shift;
    $self->test_canCreateAdditionalPaymentMethod();
    $self->test_canNotCreateAdditionalPaymentMethod();
    done_testing();
}

sub test_canCreateAdditionalPaymentMethod {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $Shop = $self->_createShop();

    my $hAttributes = {
        'Alias' => 'MyShop',
        'CanAddMultiplePaymentMethods' => 1
    };
    my $PaymentType = $self->_createSUT($hAttributes);

    my $Result = $PaymentType->canCreateAdditionalPaymentMethod($Shop);
    ok($Result,"$SubTestName - Tests if the canCreateAdditionalPaymentMethod returns 1.");
}

sub test_canNotCreateAdditionalPaymentMethod {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $Shop = $self->_createShop();

    my $hAttributes = {
        'Alias' => 'MyShop',
        'CanAddMultiplePaymentMethods' => 0,
        'MethodClass' => $self->_createPaymentMethod({})
    };
    my $PaymentType = $self->_createSUT($hAttributes);

    my $CanAddMultiplePaymentMethods = $PaymentType->canCreateAdditionalPaymentMethod($Shop);
    is($CanAddMultiplePaymentMethods, 0, "$SubTestName - Tests if the canCreateAdditionalPaymentMethod returns 0.");
}

#---------------------------------------------------------------------------
#  Helpers
#---------------------------------------------------------------------------
sub _createSUT {
    my $self = shift;
    my ($hAttributes) = @_;
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Payment::API::Object::PaymentType',
        $hAttributes
    );

    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createShop {
    my $self = shift;

    my $hAttributes = {
        'Alias' => 'MyShop',
        'PaymentMethods' => [$self->_createPaymentMethod({})]
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Shop::API::Object::Shop',
        $hAttributes
    );
    return $Mockify->getMockObject();
}

sub _createPaymentMethod {
    my $self = shift;
    my ($hAttributes) = @_;

    my $PackageName = 'DE_EPAGES::Payment::API::Object::PaymentMethod';
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new($PackageName, $hAttributes);
    $Mockify->addMockWithReturnValue('alias', 'PaymentMethod');
    $Mockify->addMockWithReturnValueAndParameterCheck('instanceOf', 1,['any']);
    return $Mockify->getMockObject();
}

__PACKAGE__->runScript();