#========================================================================================
# package      DE_EPAGES::Payment::t::unit::PaymentType_isUsable
# base         DE_EPAGES::Test::API::UnitTest::Test
#----------------------------------------------------------------------------------------
# description  unit test for method isUsable
#               in package DE_EPAGES::Payment::t::unit::PaymentType
#========================================================================================
package DE_EPAGES::Payment::t::unit::PaymentType;
use base DE_EPAGES::Test::API::UnitTest::Test;
use DateTime;
use DE_EPAGES::Test::Mock::Mockify;
use Test::More;

use strict;

sub test {
    my $self = shift;
    $self->test_PaymentTypeIsDeprecated_FeatureNotExists();

    $self->test_PaymentTypeIsDeprecated_FeatureExists_PaymentTypeIsFeatured();
    $self->test_PaymentTypeIsDeprecated_FeatureExists_PaymentTypeIsNotFeatured();

    $self->test_PaymentTypeIsNotDeprecated_FeatureNotExists();

    $self->test_PaymentTypeIsNotDeprecated_FeatureExists_PaymentTypeIsFeatured();
    $self->test_PaymentTypeIsNotDeprecated_FeatureExists_PaymentTypeIsNotFeatured();

    $self->test_PaymentTypeIsDeprecatedToday_FeatureNotExists();
    done_testing();
}
#----------------------------------------------------------------------------------------
sub test_PaymentTypeIsDeprecated_FeatureNotExists {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->_createShop();
    my $PaymentType = $self->_createSUT({
      'CurrentDate' => $self->_createDateTime(2016, 11, 24),
      'DeprecationDate' => $self->_createDateTime(2016, 10, 24),
      'ExistsFeature' => undef,
    });
    my $Result = $PaymentType->isUsable($Shop);
    is($Result, 0,"$SubTestName - Tests if the paymenttype is deprecated and the feature does not exists.");
}
#----------------------------------------------------------------------------------------
sub test_PaymentTypeIsDeprecated_FeatureExists_PaymentTypeIsFeatured {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->_createShop({
      'PaymentTypeIsFeatured' => 1,
    });
    my $PaymentType = $self->_createSUT({
      'CurrentDate' => $self->_createDateTime(2016, 11, 24),
      'DeprecationDate' => $self->_createDateTime(2016, 10, 24),
      'ExistsFeature' => 1,
    });
    my $Result = $PaymentType->isUsable($Shop);
    is($Result, 0,"$SubTestName - Tests if the paymenttype is deprecated and the feature exists and it is featured.");
}
#----------------------------------------------------------------------------------------
sub test_PaymentTypeIsDeprecated_FeatureExists_PaymentTypeIsNotFeatured {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->_createShop({
      'PaymentTypeIsFeatured' => 0,
    });
    my $PaymentType = $self->_createSUT({
      'CurrentDate' => $self->_createDateTime(2016, 11, 24),
      'DeprecationDate' => $self->_createDateTime(2016, 10, 24),
      'ExistsFeature' => 1,
    });
    my $Result = $PaymentType->isUsable($Shop);
    is($Result, 0,"$SubTestName - Tests if the paymenttype is deprecated and the feature exists and it is not featured.");
}
#----------------------------------------------------------------------------------------
sub test_PaymentTypeIsDeprecatedToday_FeatureNotExists {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $PaymentType = $self->_createSUT({
      'CurrentDate' => $self->_createDateTime(2016, 10, 24),
      'DeprecationDate' => $self->_createDateTime(2016, 10, 24),
      'ExistsFeature' => undef,
    });
    my $Result = $PaymentType->isUsable();
    is($Result, 0,"$SubTestName - Tests if the paymenttype is deprecated today and the feature does not exists.");
}
#----------------------------------------------------------------------------------------
sub test_PaymentTypeIsNotDeprecated_FeatureNotExists {
    my $self = shift;
    my $SubTestName = (caller(0))[3];


    my $Shop = $self->_createShop();
    my $PaymentType = $self->_createSUT({
      'CurrentDate' => $self->_createDateTime(2016, 9, 24),
      'DeprecationDate' => $self->_createDateTime(2016, 10, 24),
      'ExistsFeature' => undef,
      'MethodClass' => $self->_createMethodClass()
    });

    my $Result = $PaymentType->isUsable($Shop);

    is($Result, 1,"$SubTestName - Tests if the paymenttype is not deprecated and the feature does not exists.");
}
#----------------------------------------------------------------------------------------
sub test_PaymentTypeIsNotDeprecated_FeatureExists_PaymentTypeIsFeatured {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->_createShop({
      'PaymentTypeIsFeatured' => 1,
    });
    my $PaymentType = $self->_createSUT({
      'CurrentDate' => $self->_createDateTime(2016, 9, 24),
      'DeprecationDate' => $self->_createDateTime(2016, 10, 24),
      'ExistsFeature' => 1,
      'MethodClass' => $self->_createMethodClass()
    });
    my $Result = $PaymentType->isUsable($Shop);
    is($Result, 1,"$SubTestName - Tests if the paymenttype is not deprecated and the feature exists and it is featured.");
}
#----------------------------------------------------------------------------------------
sub test_PaymentTypeIsNotDeprecated_FeatureExists_PaymentTypeIsNotFeatured {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->_createShop({
      'PaymentTypeIsFeatured' => 0,
    });
    my $PaymentType = $self->_createSUT({
      'CurrentDate' => $self->_createDateTime(2016, 9, 24),
      'DeprecationDate' => $self->_createDateTime(2016, 10, 24),
      'ExistsFeature' => 1,
      'MethodClass' => $self->_createMethodClass()
    });
    my $Result = $PaymentType->isUsable($Shop);
    is($Result, 0,"$SubTestName - Tests if the paymenttype is not deprecated and the feature exists and it is not featured.");
}
#----------------------------------------------------------------------------------------
# helpers
#----------------------------------------------------------------------------------------
sub _createSUT {
    my $self = shift;
    my ($hSetup) = @_;

    my $hAttributes = {
        'DeprecationDate' => $hSetup->{'DeprecationDate'},
        'MethodClass' => $hSetup->{'MethodClass'}
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Payment::API::Object::PaymentType',
        $hAttributes
    );
    $Mockify->mock('_GetCurrentDateTime', $hSetup->{'CurrentDate'});
    $Mockify->mock('_ExistsFeatureByAlias', $hSetup->{'ExistsFeature'},[{'string' => 'MyFeatureName'}]);

    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createDateTime {
    my $self = shift;
    my ($Year, $Month, $Day) = @_;
    return DateTime->new(
      year       => $Year,
      month      => $Month,
      day        => $Day,
  );
}
#----------------------------------------------------------------------------------------
sub _createShop {
    my $self = shift;
    my ($hSetup) = @_;

    my $hAttributes = {
        'Alias' => 'MyShop'
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Shop::API::Object::Shop',
        $hAttributes
    );

    $Mockify->mock('featureMaxValue', $hSetup->{'PaymentTypeIsFeatured'}, [{'string' => 'MyFeatureName'}]);
    return $Mockify->getMockObject();
}
#----------------------------------------------------------------------------------------
sub _createMethodClass {
    my $self = shift;

    my $hAttributes = {
        'FeatureName' => 'MyFeatureName'
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Object::API::Object::Class',
        $hAttributes
    );

    return $Mockify->getMockObject();
}
__PACKAGE__->runScript();