#========================================================================================
# package      DE_EPAGES::Payment::t::unit::UI_Shop
# base         DE_EPAGES::Test::API::UnitTest::Test
#----------------------------------------------------------------------------------------
# description  unit test for Shop controller
#========================================================================================
package DE_EPAGES::Payment::t::unit::UI_Shop;
use base DE_EPAGES::Test::API::UnitTest::Test;
use DE_EPAGES::Test::Mock::Mockify;
use DE_EPAGES::Test::Mock::MockifyServlet;
use Test::More;

use strict;

sub test {
    my $self = shift;

    $self->_buildMocks();

    $self->test_ViewPaymentGroupDetails();
    done_testing();
}

sub test_ViewPaymentGroupDetails {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $SUT = $self->memory()->get('SUT');
    my $Servlet = $self->memory()->get('Servlet');

    $SUT->ViewPaymentGroupDetails($Servlet);

    my $hExpectedVars = {
       'PaymentGroup' => {
            'PaymentTypes' => [
                {
                    'PaymentType' => 'TLEHash',
                    'CanCreateAdditionalPaymentMethod' => 1
                }
            ],
            'PaymentGroup' => 'TLEHash',
        },
        'MaxFeatureValuePaymentMethodsReached' => 0
    };

    is_deeply($Servlet->vars(), $hExpectedVars, "$SubTestName - Test if the Servlet vars are set as expected");
}
#----------------------------------------------------------------------------------------
# helpers
#----------------------------------------------------------------------------------------
sub _buildMocks {
    my $self = shift;

    my $aPaymentTypes = $self->_createPaymentTypes();
    my $SUT = $self->_createSUT();
    my $Shop = $self->_createShop($aPaymentTypes);
    my $Servlet = $self->_createServlet($Shop);
    $self->memory()->add('SUT', $SUT);
    $self->memory()->add('Shop', $Shop);
    $self->memory()->add('Servlet', $Servlet);
}

sub _createShop {
    my $self = shift;
    my ($aPaymentTypes) = @_;

    my $Mockify = $self->mockFactory()->buildShop({
        'Alias' => 'TestShop',
    });
    $Mockify->addMockWithReturnValueAndParameterCheck('loadObject', $self->_createPaymentGroup($aPaymentTypes), [
        {'string' => '1337'},
        {'string' => 'PaymentGroup'},
        {'hashref' => {'AllowSystemSite' => 1}}
    ]);

    return $Mockify->getMockObject();
}

sub _createSUT {
    my $self = shift;

    my $aParameterList = [];
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new(
        'DE_EPAGES::Payment::UI::Shop',
        $aParameterList
    );
    $Mockify->addMockWithReturnValueAndParameterCheck('_createShopUtil', $self->_createShopUtil(), [{'object' => 'DE_EPAGES::Shop::API::Object::Shop'}]);

    return $Mockify->getMockObject();
}

sub _createServlet {
    my $self = shift;
    my ($Shop) = @_;

    my $MockifyServlet = DE_EPAGES::Test::Mock::MockifyServlet->new($Shop);
    $MockifyServlet->addParam('PaymentGroupID', '1337');

    return $MockifyServlet->getMockObject();
}

sub _createPaymentTypes {
    my $self = shift;
    return [$self->_createPaymentType()];
}

sub _createPaymentType {
    my $self = shift;

    my $aParameterList = [];
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new(
        'DE_EPAGES::Payment::API::Object::PaymentType',
        $aParameterList
    );
    $Mockify->addMockWithReturnValue('tleHash', {'PaymentType' => 'TLEHash'});
    $Mockify->addMockWithReturnValueAndParameterCheck('canCreateAdditionalPaymentMethod', 1, [{'object' => 'DE_EPAGES::Shop::API::Object::Shop'}]);

    return $Mockify->getMockObject();
}

sub _createPaymentGroup {
    my $self = shift;
    my ($aPaymentTypes) = @_;

    my $aParameterList = [];
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new(
        'DE_EPAGES::Payment::API::Object::PaymentGroup',
        $aParameterList
    );
    $Mockify->addMockWithReturnValue('tleHash', {'PaymentGroup' => 'TLEHash',});
    $Mockify->addMockWithReturnValueAndParameterCheck('getPaymentTypes', $aPaymentTypes, [{'object' => 'DE_EPAGES::Shop::API::Object::Shop'}]);

    return $Mockify->getMockObject();
}

sub _createShopUtil {
    my $self = shift;

    my $aParameterList = [$self->_createShop()];
    my $Mockify = DE_EPAGES::Test::Mock::Mockify->new(
        'DE_EPAGES::Shop::API::ShopUtil',
        $aParameterList
    );
    $Mockify->addMockWithReturnValueAndParameterCheck('maxFeatureValuePaymentMethodsReached', 0, [{'object' => 'DE_EPAGES::Shop::API::Object::Shop'}]);

    return $Mockify->getMockObject();
}

__PACKAGE__->runScript();