#!/srv/epages/eproot/Perl/bin/perl

use strict;
use Getopt::Long;

use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Database::API::Connection qw( RunOnStore );
use DE_EPAGES::Object::API::Factory qw( LoadObjectByPath );
use DE_EPAGES::Core::API::Password qw ( CryptPassword );

sub usage {
    print <<END_USAGE;
Description:
    This script updates password of user in database storename.

Usage:
    $0 [options] [flags]

options:
    -storename    name of store      ()
    -user         user object path   ()
    -password     user password      ()
flags:
    -help         show the command line options

Example:
    $0 -storename Store -user /Users/wsadmin -password wsadmin
    $0 -storename Site -user /Users/tboadmin -password tboadmin
    $0 -storename Site -user /Providers/Distributor/Users/admin -password admin
END_USAGE
    exit 2;
}

sub Main {

    local $| = 1;

    my %Options = ();
    my @GetOpt = qw(help storename=s user=s password=s);

    usage() unless GetOptions(\%Options, @GetOpt);
    usage() if defined $Options{help};
    usage() unless defined $Options{storename};
    usage() unless defined $Options{user};
    usage() unless defined $Options{password};

    RunOnStore(
        Store => $Options{storename},
        Sub => sub {
            my $User = LoadObjectByPath($Options{user});
            die "user does not exists: $Options{user}" unless defined $User;
            my $NewPassword = CryptPassword( $Options{password} );
            die "Can't crypt password: $Options{password}" unless defined $NewPassword;
            $User->set({Password => $NewPassword });
    });
}

RunScript(
    'Sub' => \&Main
);

1;
