#========================================================================================
# package      DE_EPAGES::Shop::API::Feature
# state        public
#----------------------------------------------------------------------------------------
# description  This package provides the feature functions.
#========================================================================================
package DE_EPAGES::Shop::API::Feature;
use base Exporter;
use strict;

our @EXPORT_OK = qw (
    LoadFeatureByAlias
    ExistsFeatureByAlias
);

use DE_EPAGES::Core::API::TestParameter qw ( TestString );
use DE_EPAGES::Object::API::Factory qw ( LoadRootObject );

#========================================================================================
# function     LoadFeatureByAlias
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Feature = LoadFeatureByAlias( $Alias );
#----------------------------------------------------------------------------------------
# example      $Feature = LoadFeatureByAlias( 'OrderDocument' );
#----------------------------------------------------------------------------------------
# description  Returns the feature object.
#----------------------------------------------------------------------------------------
# input        $Alias | feature alias | string
# return       $Feature | feature object | DE_EPAGES::Shop::API::Object::Feature
#========================================================================================
sub LoadFeatureByAlias {
    my ($Alias) = @_;
    TestString( 'Alias', $Alias );

    return LoadRootObject()->child('Features')->child($Alias);
}

#========================================================================================
# function     ExistsFeatureByAlias
# state        public
#----------------------------------------------------------------------------------------
# syntax       $ExistsFeature = ExistsFeatureByAlias( $Alias );
#----------------------------------------------------------------------------------------
# example      $ExistsFeature = ExistsFeatureByAlias( 'OrderDocument' );
#----------------------------------------------------------------------------------------
# description  Returns true if the feature exists
#----------------------------------------------------------------------------------------
# input        $Alias | feature alias | string
# return       $ExistsFeature | boolean
#========================================================================================
sub ExistsFeatureByAlias {
    my ($Alias) = @_;

    return LoadRootObject()->child('Features')->existsChild($Alias);

}

1;
