#========================================================================================
# package      DE_EPAGES::Shop::API::System
# state        public
#----------------------------------------------------------------------------------------
# description  This package provides the system functions.
#========================================================================================
package DE_EPAGES::Shop::API::System;
use base Exporter;
use strict;

our @EXPORT_OK = qw (
    SynchronizeUnityBaseURL
    GetUnityShopIDs
);

use DE_EPAGES::Database::API::Connection qw( GetCurrentDBHandle );
use DE_EPAGES::Object::API::Factory qw ( LoadObject LoadClassByAlias );
use DE_EPAGES::Shop::API::Feature qw ( LoadFeatureByAlias );

#========================================================================================
# function     SynchronizeUnityBaseURL
# state        public
#----------------------------------------------------------------------------------------
# syntax       SynchronizeUnityBaseURL( $UnityBaseURL );
#----------------------------------------------------------------------------------------
# description  For all shops with the feature Unity of the current DB the Unity DB is
#               is updated with the given UnityBaseURL
#----------------------------------------------------------------------------------------
# input        $UnityBaseURL | UnityBaseURL | string
#========================================================================================
sub SynchronizeUnityBaseURL {
    my ($UnityBaseURL) = @_;

    my $aShopIDs = GetUnityShopIDs();

    return unless scalar @$aShopIDs;

    # update jrest parameters
    my $hContent->{'jrest'}  = {
        'baseUrl'  => $UnityBaseURL
    };

    foreach my $ShopID (@$aShopIDs) {
        my $Shop = LoadObject($ShopID);
        # send PATCH call to Unity DB
        $Shop->sendUnityApiPatchCall($hContent);
    }

    return;
}

#========================================================================================
# function     GetUnityShopIDs
# state        public
#----------------------------------------------------------------------------------------
# syntax       GetUnityShopIDs();
#----------------------------------------------------------------------------------------
# description  Returns an array of all shop IDs of the current DB by executing the
#               related SQL command
#----------------------------------------------------------------------------------------
# return        $aShopIDs | array of all Unity shop IDs | array.ref
#========================================================================================
sub GetUnityShopIDs {

    my $dbi = GetCurrentDBHandle();
    my $FeatureID = LoadFeatureByAlias('Unity')->id;
    my $AttributeID = LoadClassByAlias('Shop')->attribute('IsUnityRegistered')->id;
    # get all Unity shops of the current DB
    my $sql = <<'END_SQL';
SELECT distinct shopid
FROM shopfeature as sf
INNER JOIN booleanattribute as b ON b.objectid = sf.shopid AND b.attributeid = ? AND b.value = 1
WHERE sf.featureid = ?
AND sf.maxval = 1
END_SQL
    my $aaRows = $dbi->execute($sql, [$AttributeID, $FeatureID]);
    my @ShopIDs = map { $_->[0] } @$aaRows;

    return \@ShopIDs;
}

1;
