#========================================================================================
# package      DE_EPAGES::Shop::t::unit::ShopUtil_maxFeatureValuePaymentMethodsReached
# base         DE_EPAGES::Test::API::UnitTest::Test
#----------------------------------------------------------------------------------------
# description  unit test method: maxFeatureValuePaymentMethodsReached
#               of package: ShopUtil.pm
#========================================================================================
package DE_EPAGES::Shop::t::unit::ShopUtil_maxFeatureValuePaymentMethodsReached;
use base DE_EPAGES::Test::API::UnitTest::Test;
use DE_EPAGES::Test::Mock::MockifyEpagesObject ;
use Test::More;
use Test::Exception;
use DE_EPAGES::Shop::API::ShopUtil;
use strict;

sub test {
    my $self = shift;

    $self->test_EnoughFeaturesLeft();
    $self->test_NotEnoughFeaturesLeft();
    $self->test_MorePaymentMethodsThanFeatures();

    done_testing();
}

#----------------------------------------------------------------------------------------
sub test_EnoughFeaturesLeft {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->_createShop({
      'FeatureCurrentValue' => 1,
      'FeatureMaxValue' => 2,
    });
    my $ShopUtil = DE_EPAGES::Shop::API::ShopUtil->new($Shop);

    my $Result = $ShopUtil->maxFeatureValuePaymentMethodsReached();

    is($Result, 0, "$SubTestName - Tests if there enough features left.");
}
#----------------------------------------------------------------------------------------
sub test_NotEnoughFeaturesLeft {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Shop = $self->_createShop({
      'FeatureCurrentValue' => 1,
      'FeatureMaxValue' => 1,
    });
    my $ShopUtil = DE_EPAGES::Shop::API::ShopUtil->new($Shop);
    my $Result = $ShopUtil->maxFeatureValuePaymentMethodsReached();

    is($Result, 1, "$SubTestName - Tests if there not enough features left.");
}
#----------------------------------------------------------------------------------------
sub test_MorePaymentMethodsThanFeatures {
    my $self = shift;
    my $SubTestName = (caller(0))[3];
    my $Shop = $self->_createShop({
      'FeatureCurrentValue' => 2,
      'FeatureMaxValue' => 1,
    });
    my $ShopUtil = DE_EPAGES::Shop::API::ShopUtil->new($Shop);
    my $Result = $ShopUtil->maxFeatureValuePaymentMethodsReached();

    is($Result, 1, "$SubTestName - Tests if there not enough features left.");
}

#----------------------------------------------------------------------------------------
# helpers
#----------------------------------------------------------------------------------------
sub _createShop {
    my $self = shift;
    my ( $hSetup ) = @_;

    my $hAttributes = {
        'Alias' => 'MyShop',
    };
    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Shop::API::Object::Shop',
        $hAttributes
    );

    $Mockify->mock('featureMaxValue', $hSetup->{'FeatureMaxValue'}, [{'string' => 'PaymentMethods'}]);
    $Mockify->mock('featureCurrentValue', $hSetup->{'FeatureCurrentValue'}, [{'string' => 'PaymentMethods'}]);
    return $Mockify->getMockObject();
}
__PACKAGE__->runScript();